# LangSmith Client SDK

**Deprecated:** For the up-to-date langsmith client SDK, see the [langsmith](https://pypi.org/project/langsmith) package (https://pypi.org/project/langsmith).


This package contain(ed) the python client for interacting with the [LangSmith platform](https://smith.langchain.com/).

To install:

```bash
pip install -U langsmith
```

## Additional Documentation

To learn more about the LangSmith platform, check out the [docs](https://docs.smith.langchain.com/docs/).
